%define upstream_name    Lexical-SealRequireHints
%define upstream_version 0.011

Name:       perl-%{upstream_name}
Version:    %perl_convert_version %{upstream_version}
Release:    %mkrel 7

Summary:    Prevent leakage of lexical hints
License:    GPL+ or Artistic
Group:      Development/Perl
Url:        https://metacpan.org/release/%{upstream_name}
Source0:    https://cpan.metacpan.org/modules/by-module/Lexical/%{upstream_name}-%{upstream_version}.tar.gz

BuildRequires: perl(Module::Build)
BuildRequires: perl(Test::More) >= 0.410.0
BuildRequires: perl(strict)
BuildRequires: perl(warnings)
BuildRequires: perl-devel
%{?perl_default_filter}

%description
This module works around two historical bugs in Perl's handling of the
'%^H' (lexical hints) variable. One bug causes lexical state in one file to
leak into another that is 'require'd/'use'd from it. This bug, [perl
#68590], was present from Perl 5.6 up to Perl 5.10, fixed in Perl 5.11.0.
The second bug causes lexical state (normally a blank '%^H' once the first
bug is fixed) to leak outwards from 'utf8.pm', if it is automatically
loaded during Unicode regular expression matching, into whatever source is
compiling at the time of the regexp match. This bug, [perl #73174], was
present from Perl 5.8.7 up to Perl 5.11.5, fixed in Perl 5.12.0.

Both of these bugs seriously damage the usability of any module relying on
'%^H' for lexical scoping, on the affected Perl versions. It is in practice
essential to work around these bugs when using such modules. On versions of
Perl that require such a workaround, this module globally changes the
behaviour of 'require', including 'use' and the implicit 'require'
performed in Unicode regular expression matching, so that it no longer
exhibits these bugs.

The workaround supplied by this module takes effect the first time its
'import' method is called. Typically this will be done by means of a 'use'
statement. This should be done as early as possible, because it only
affects 'require'/'use' statements that are compiled after the workaround
goes into effect. For 'use' statements, and 'require' statements that are
executed immediately and only once, it suffices to invoke the workaround
when loading the first module that will set up vulnerable lexical state.
Delayed-action 'require' statements, however, are more troublesome, and can
require the workaround to be loaded much earlier. Ultimately, an affected
Perl program may need to load the workaround as very nearly its first
action. Invoking this module multiple times, from multiple modules, is not
a problem: the workaround is only applied once, and applies to everything
subsequently compiled.

%prep
%setup -q -n %{upstream_name}-%{upstream_version}

%build
%__perl Build.PL --installdirs=vendor

./Build CFLAGS="%{optflags}"

%check
./Build test

%install
./Build install --destdir=%{buildroot}

%files
%doc Changes META.json META.yml MYMETA.yml README SIGNATURE
%{_mandir}/man3/*
%perl_vendorarch/*

%changelog
* Sat Jul 18 2020 tv <tv> 0.11.0-7.mga8
+ Revision: 1606983
- rebuild for perl-5.32 (binary package w/o a dep on libperl.so

* Wed Feb 12 2020 umeabot <umeabot> 0.11.0-6.mga8
+ Revision: 1508357
- Mageia 8 Mass Rebuild

* Fri Sep 21 2018 umeabot <umeabot> 0.11.0-5.mga7
+ Revision: 1293315
- Mageia 7 Mass Rebuild

* Wed Aug 08 2018 pterjan <pterjan> 0.11.0-4.mga7
+ Revision: 1249506
- Rebuild for perl 5.28

* Tue Oct 03 2017 tv <tv> 0.11.0-3.mga7
+ Revision: 1165112
- rebuild with fixed rpm for missing autodeps

* Thu Aug 31 2017 pterjan <pterjan> 0.11.0-2.mga7
+ Revision: 1149009
- Rebuild for perl ABI changes

* Sat Jul 22 2017 shlomif <shlomif> 0.11.0-1.mga7
+ Revision: 1128680
- update to 0.011

* Sun Jun 19 2016 pterjan <pterjan> 0.10.0-2.mga6
+ Revision: 1029133
- Rebuild for perl 5.22.2

* Thu Mar 24 2016 shlomif <shlomif> 0.10.0-1.mga6
+ Revision: 994782
- update to 0.010

* Fri Feb 12 2016 umeabot <umeabot> 0.9.0-3.mga6
+ Revision: 957614
- Mageia 6 Mass Rebuild

* Fri Jun 26 2015 tv <tv> 0.9.0-2.mga6
+ Revision: 844939
- rebuild for soname-ifed perl

* Tue Jun 23 2015 shlomif <shlomif> 0.9.0-1.mga6
+ Revision: 840517
- New version 0.009 + Rebuild for new perl

* Wed Oct 15 2014 umeabot <umeabot> 0.7.0-8.mga5
+ Revision: 746707
- Second Mageia 5 Mass Rebuild

* Tue Sep 30 2014 tv <tv> 0.7.0-7.mga5
+ Revision: 733106
- add exclude

* Tue Sep 16 2014 umeabot <umeabot> 0.7.0-6.mga5
+ Revision: 685200
- Mageia 5 Mass Rebuild

* Tue Jun 03 2014 pterjan <pterjan> 0.7.0-5.mga5
+ Revision: 631368
- Rebuild for perl 5.20

* Sat Oct 19 2013 umeabot <umeabot> 0.7.0-4.mga4
+ Revision: 524367
- Mageia 4 Mass Rebuild

* Wed May 29 2013 jquelin <jquelin> 0.7.0-3.mga4
+ Revision: 430771
- perl 5.18.0 rebuild

* Sun Jan 13 2013 umeabot <umeabot> 0.7.0-2.mga3
+ Revision: 368990
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Aug 05 2012 shlomif <shlomif> 0.7.0-1.mga3
+ Revision: 278661
- imported package perl-Lexical-SealRequireHints

